@@ -19,30 +19,7 @@ class DeviceController(Device):
     TYPE_USB             = "usb"
     TYPE_PCI             = "pci"
     TYPE_CCID            = "ccid"
-
-    @staticmethod
-    def get_recommended_types(_guest):
-        return [DeviceController.TYPE_SCSI,
-                DeviceController.TYPE_USB,
-                DeviceController.TYPE_VIRTIOSERIAL,
-                DeviceController.TYPE_CCID]
-
-    @staticmethod
-    def pretty_type(ctype):
-        pretty_mappings = {
-            DeviceController.TYPE_IDE:             "IDE",
-            DeviceController.TYPE_FDC:              _("Floppy"),
-            DeviceController.TYPE_SCSI:            "SCSI",
-            DeviceController.TYPE_SATA:            "SATA",
-            DeviceController.TYPE_VIRTIOSERIAL:    "VirtIO Serial",
-            DeviceController.TYPE_USB:             "USB",
-            DeviceController.TYPE_PCI:             "PCI",
-            DeviceController.TYPE_CCID:            "CCID",
-       }
-
-        if ctype not in pretty_mappings:
-            return ctype
-        return pretty_mappings[ctype]
+    TYPE_XENBUS          = "xenbus"
 
     @staticmethod
     def get_usb2_controllers(conn):
@@ -77,41 +54,59 @@ class DeviceController(Device):
         ctrl = DeviceController(conn)
         ctrl.type = "usb"
         ctrl.model = "nec-xhci"
-        if conn.check_support(conn.SUPPORT_CONN_QEMU_XHCI):
+        if conn.support.conn_qemu_xhci():
             ctrl.model = "qemu-xhci"
-        if conn.check_support(conn.SUPPORT_CONN_USB3_PORTS):
+        if conn.support.conn_usb3_ports():
             # 15 is the max ports qemu supports, might as well
             # Add as many as possible
             ctrl.ports = 15
         return ctrl
 
 
-    _XML_PROP_ORDER = ["type", "index", "model", "master_startport"]
+    _XML_PROP_ORDER = ["type", "index", "model", "master_startport",
+            "driver_queues", "maxGrantFrames"]
 
     type = XMLProperty("./@type")
     model = XMLProperty("./@model")
     vectors = XMLProperty("./@vectors", is_int=True)
     ports = XMLProperty("./@ports", is_int=True)
-    master_startport = XMLProperty("./master/@startport", is_int=True)
-
+    maxGrantFrames = XMLProperty("./@maxGrantFrames", is_int=True)
     index = XMLProperty("./@index", is_int=True)
 
-    def pretty_desc(self):
-        ret = self.pretty_type(self.type)
-        if self.type == "scsi":
-            if self.model == "virtio-scsi":
-                ret = "Virtio " + ret
-            elif self.address.type == "spapr-vio":
-                ret = "sPAPR " + ret
-        if self.type == "pci" and self.model == "pcie-root":
-            ret = "PCIe"
+    driver_iothread = XMLProperty("./driver/@iothread", is_int=True)
+    driver_queues = XMLProperty("./driver/@queues", is_int=True)
+
+    master_startport = XMLProperty("./master/@startport", is_int=True)
+
+
+    def _get_attached_disk_devices(self, guest):
+        ret = []
+        for disk in guest.devices.disk:
+            if (self.type == disk.bus and
+                self.index == disk.address.controller):
+                ret.append(disk)
         return ret
 
+    def _get_attached_virtioserial_devices(self, guest):
+        ret = []
+        for dev in guest.devices.channel:
+            if (self.type == dev.address.type and
+                self.index == dev.address.controller):
+                ret.append(dev)
+        for dev in guest.devices.console:
+            # virtio console is implied to be on virtio-serial index=0
+            if self.index == 0 and dev.target_type == "virtio":
+                ret.append(dev)
+        return ret
 
-    ##################
-    # Default config #
-    ##################
-
-    def set_defaults(self, _guest):
-        if self.index is None:
-            self.index = 0
+    def get_attached_devices(self, guest):
+        """
+        Return all the Device objects from the passed Guest that are attached
+        to this controller
+        """
+        ret = []
+        if self.type == "virtio-serial":
+            ret = self._get_attached_virtioserial_devices(guest)
+        elif self.type in ["scsi", "sata", "ide", "fdc"]:
+            ret = self._get_attached_disk_devices(guest)
+        return ret
